==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkPDataSetWriter.java <==
// java wrapper for vtkPDataSetWriter object
//

package vtk;
import vtk.*;

public class vtkPDataSetWriter extends vtkDataSetWriter
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Write_2();
  public int Write()
    { return Write_2(); }

  private native void SetNumberOfPieces_3(int id0);
  public void SetNumberOfPieces(int id0)
    { SetNumberOfPieces_3(id0); }

  private native int GetNumberOfPieces_4();
  public int GetNumberOfPieces()
    { return GetNumberOfPieces_4(); }

  private native void SetGhostLevel_5(int id0);
  public void SetGhostLevel(int id0)
    { SetGhostLevel_5(id0); }

  private native int GetGhostLevel_6();
  public int GetGhostLevel()
    { return GetGhostLevel_6(); }

  private native void SetStartPiece_7(int id0);
  public void SetStartPiece(int id0)
    { SetStartPiece_7(id0); }

  private native int GetStartPiece_8();
  public int GetStartPiece()
    { return GetStartPiece_8(); }

  private native void SetEndPiece_9(int id0);
  public void SetEndPiece(int id0)
    { SetEndPiece_9(id0); }

  private native int GetEndPiece_10();
  public int GetEndPiece()
    { return GetEndPiece_10(); }

  private native void SetFilePattern_11(String id0);
  public void SetFilePattern(String id0)
    { SetFilePattern_11(id0); }

  private native String GetFilePattern_12();
  public String GetFilePattern()
    { return GetFilePattern_12(); }

  private native void SetUseRelativeFileNames_13(int id0);
  public void SetUseRelativeFileNames(int id0)
    { SetUseRelativeFileNames_13(id0); }

  private native int GetUseRelativeFileNames_14();
  public int GetUseRelativeFileNames()
    { return GetUseRelativeFileNames_14(); }

  private native void UseRelativeFileNamesOn_15();
  public void UseRelativeFileNamesOn()
    { UseRelativeFileNamesOn_15(); }

  private native void UseRelativeFileNamesOff_16();
  public void UseRelativeFileNamesOff()
    { UseRelativeFileNamesOff_16(); }

  private native void SetController_17(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_17(id0); }

  private native long GetController_18();
  public vtkMultiProcessController GetController() {
    long temp = GetController_18();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkPDataSetWriter() { super(); }

  public vtkPDataSetWriter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-3-armv7h.pkg.tar.xz: vtk/vtkPDataSetWriter.java <==
// java wrapper for vtkPDataSetWriter object
//

package vtk;
import vtk.*;

public class vtkPDataSetWriter extends vtkDataSetWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Write_2();
  public int Write()
    { return Write_2(); }

  private native void SetNumberOfPieces_3(int id0);
  public void SetNumberOfPieces(int id0)
    { SetNumberOfPieces_3(id0); }

  private native int GetNumberOfPieces_4();
  public int GetNumberOfPieces()
    { return GetNumberOfPieces_4(); }

  private native void SetGhostLevel_5(int id0);
  public void SetGhostLevel(int id0)
    { SetGhostLevel_5(id0); }

  private native int GetGhostLevel_6();
  public int GetGhostLevel()
    { return GetGhostLevel_6(); }

  private native void SetStartPiece_7(int id0);
  public void SetStartPiece(int id0)
    { SetStartPiece_7(id0); }

  private native int GetStartPiece_8();
  public int GetStartPiece()
    { return GetStartPiece_8(); }

  private native void SetEndPiece_9(int id0);
  public void SetEndPiece(int id0)
    { SetEndPiece_9(id0); }

  private native int GetEndPiece_10();
  public int GetEndPiece()
    { return GetEndPiece_10(); }

  private native void SetFilePattern_11(String id0);
  public void SetFilePattern(String id0)
    { SetFilePattern_11(id0); }

  private native String GetFilePattern_12();
  public String GetFilePattern()
    { return GetFilePattern_12(); }

  private native void SetUseRelativeFileNames_13(int id0);
  public void SetUseRelativeFileNames(int id0)
    { SetUseRelativeFileNames_13(id0); }

  private native int GetUseRelativeFileNames_14();
  public int GetUseRelativeFileNames()
    { return GetUseRelativeFileNames_14(); }

  private native void UseRelativeFileNamesOn_15();
  public void UseRelativeFileNamesOn()
    { UseRelativeFileNamesOn_15(); }

  private native void UseRelativeFileNamesOff_16();
  public void UseRelativeFileNamesOff()
    { UseRelativeFileNamesOff_16(); }

  private native void SetController_17(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_17(id0); }

  private native long GetController_18();
  public vtkMultiProcessController GetController() {
    long temp = GetController_18();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkPDataSetWriter() { super(); }

  public vtkPDataSetWriter(long id) { super(id); }
  public native long   VTKInit();

}
